geowatch.demo package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   geowatch.demo.metrics_demo

Submodules
----------

.. toctree::
   :maxdepth: 4

   geowatch.demo.demo_region
   geowatch.demo.dummy_demodata
   geowatch.demo.landsat_demodata
   geowatch.demo.nitf_demodata
   geowatch.demo.sentinel2_demodata
   geowatch.demo.smart_kwcoco_demodata
   geowatch.demo.stac_demo

Module contents
---------------

.. automodule:: geowatch.demo
   :members:
   :undoc-members:
   :show-inheritance:
